@@ -1,8 +1,9 @@
 from django.contrib.gis.gdal import CoordTransform, SpatialReference
+from django.contrib.gis.geos import GEOSGeometry
 from rgd.models.constants import DB_SRID
 
 
-def transform_geometry(geometry, source_wkt):
+def transform_geometry(geometry: GEOSGeometry, source_wkt: str):
     """Transform geometry into the database's spatial reference system."""
     source = SpatialReference(source_wkt)
     dest = SpatialReference(DB_SRID)
